@@ -68,6 +68,8 @@ class Database(core.Construct):
         database_cluster_parameters_group_name (str):  The name of the DB cluster parameter group to associate with this DB cluster. This parameter depends on the Database Engine version you previously selected. In case you leave blank the version use default.aurora-mysql5.7 or default.aurora-postgresql10. If this argument is omitted, default.aurora5.6 is used. If default.aurora5.6 is used, specifying aurora-mysql or aurora-postgresql for the Engine property might result in an error. More info https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-rds-database-instance.html#cfn-rds-dbinstance-engineversion
         
         parameter_group (aws_rds.ParameterGroup): The parameter group to assign to the database
+        
+        option_group (aws_rds.OptionGroup): The option group to assign to the database
 
         database_allocated_storage (str): The size of the allocated space for the database. This is GB
         
@@ -141,6 +143,7 @@ class Database(core.Construct):
         database_engine_version=None,
         database_cluster_parameters_group_name=None,
         parameter_group=None,
+        option_group=None, 
         database_allocated_storage=None,
         database_will_send_email=False,
         tag_scheduler_uptime="",
@@ -175,9 +178,10 @@ class Database(core.Construct):
         is_oracle = "oracle" in database_engine
 
         has_no_parameter_group = parameter_group is None and database_cluster_parameters_group_name is None
-
         has_no_defult_parameter_group = has_no_parameter_group and engine_to_cluster_parameter_group_family[database_engine] is None
 
+        has_no_option_group = option_group is None
+
         sends_emails = (
             database_will_send_email
             and isinstance(database_will_send_email, str)
@@ -332,6 +336,16 @@ class Database(core.Construct):
         # RDS Instance
         # ~~~~~~~~~~~~~~~~
         if is_not_cluster_compatible:
+
+            if is_oracle:
+                oracle_oem_client_security_group = _ec2.SecurityGroup.from_security_group_id(
+                    self,
+                    "oracle_oem_client_security_group",
+                    aws_account["oracle_oem_client_security_group"],
+                    mutable=False,
+                )
+                security_groups.append(oracle_oem_client_security_group)
+
             self._instance = _rds.DatabaseInstance(
                 self,
                 "instance",
@@ -341,7 +355,7 @@ class Database(core.Construct):
                 database_name=database_name if database_name else None,
                 license_model=_rds.LicenseModel.BRING_YOUR_OWN_LICENSE if is_oracle else None,
                 credentials=credentials,
-                # parameter_group=my_parameter_group,
+                parameter_group=my_parameter_group,
                 instance_type=instance_type,
                 vpc=vpc,
                 auto_minor_version_upgrade=True,
@@ -351,7 +365,7 @@ class Database(core.Construct):
                 instance_identifier=identifier_prefix + "db",
                 # max_allocated_storage=None,
                 multi_az=is_production,
-                # option_group=None,
+                option_group=None if has_no_option_group else option_group,
                 preferred_maintenance_window="mon:03:00-mon:04:00",
                 processor_features=None,
                 security_groups=security_groups,
