@@ -1533,8 +1533,8 @@ class Microservice(core.Construct):
             if(network_load_balancer_source_autoscaling_group is not None):
                 role = _iam.Role(
                     self,
-                    "manage_connection_to_nlb_instance_role",
-                    description="manage_connection_to_nlb_instance_role",
+                    app_name + "_" + main_component_name + "_manage_connection_to_nlb_instance_role",
+                    description=app_name + "_" + main_component_name + "_manage_connection_to_nlb_instance_role",
                     assumed_by=_iam.ServicePrincipal("lambda.amazonaws.com"),
                     managed_policies=[
                         # AWS managed policy to allow sending logs and custom metrics to CloudWatch
@@ -1542,13 +1542,13 @@ class Microservice(core.Construct):
                             "service-role/AWSLambdaBasicExecutionRole"
                         )
                     ],
-                    role_name="manage_connection_to_nlb_instance_role",
+                    role_name=app_name + "_" + main_component_name + "_manage_connection_to_nlb_instance_role",
                 )
 
                 role.attach_inline_policy(
                     _iam.Policy(
                         self,
-                        "manage_nlb_instance_security_group_policy",
+                        app_name + "_" + main_component_name + "_manage_nlb_instance_security_group_policy",
                         statements=[
                             # Policy for EBS
                             _iam.PolicyStatement(
@@ -1573,7 +1573,7 @@ class Microservice(core.Construct):
                     self, "configuration_bucket", aws_account["s3_config_bucket"]
                 )
 
-                lambda_function = _lambda.Function(self, "manage_connection_to_nlb_instance_security_group_ingress",
+                lambda_function = _lambda.Function(self, app_name + "_" + main_component_name + "_manage_connection_to_nlb_instance_security_group_ingress",
                     runtime=_lambda.Runtime.NODEJS_12_X,
                     code=_lambda.Code.from_asset(
                         path=os.path.join(dirname, './manage_connection_to_nlb_instance_security_group_ingress')
